#include "mainwindow.h"

MainWindow::MainWindow(QRect sr, QWidget *parent)
    : QMainWindow(parent),screenRect(sr)
{
    setWindowTitle(tr("Snake 3D"));
    readScore();

    //qDebug("%i,%i",screenRect.width(),screenRect.height());

    openMainMenu();
}

MainWindow::~MainWindow()
{
}

void MainWindow::openMainMenu()
{
    showNormal();
    setFixedSize(600, 400);
    MainM *mainm = new MainM(this);
    setCentralWidget(mainm);

    connect(mainm,SIGNAL(spSignal()),this,SLOT(openSingleOpt()));
    connect(mainm,SIGNAL(mpSignal()),this,SLOT(openMultiMenu()));
    connect(mainm,SIGNAL(helpSignal()),this,SLOT(openHelp()));
    connect(mainm,SIGNAL(scoreSignal()),this,SLOT(openScore()));
    connect(mainm,SIGNAL(closeSignal()),this,SLOT(close()));
}

void MainWindow::play(SOptions o)
{
    opts = o;
    writeOpts();

    if (o.bFullscreen)
    {
        showFullScreen();
        o.iWidth = screenRect.width();
        o.iHeight = screenRect.height();
    }
    else
    {
        setGeometry((screenRect.width()-o.iWidth)/2, (screenRect.height()-o.iHeight)/2,o.iWidth, o.iHeight);
        setFixedSize(o.iWidth, o.iHeight);
    }

    OpenGLWidget *gl = new OpenGLWidget(&o,this);
    setCentralWidget(gl);
    connect(gl,SIGNAL(cancel()),this,SLOT(openMainMenu()));
    connect(gl,SIGNAL(scored(SScoreData *)),this,SLOT(receiveScore(SScoreData *)));
}

void MainWindow::openMultiMenu()
{
    readOpts();

    int len = 4;
    if(top10[0].iScore < 1000) --len;
    if(top10[0].iScore < 500) --len;
    if(top10[0].iScore < 100) --len;
    if(top10[0].iScore < 50) --len;

    splitOpts *spop = new splitOpts(len,opts,this);
    setCentralWidget(spop);

    connect(spop,SIGNAL(playSignal(SOptions)),this,SLOT(play(SOptions)));
    connect(spop,SIGNAL(backSignal()),this,SLOT(openMainMenu()));
}

void MainWindow::openSingleOpt()
{
    readOpts();

    int len = 4;
    if(top10[0].iScore < 1000) --len;
    if(top10[0].iScore < 500) --len;
    if(top10[0].iScore < 100) --len;
    if(top10[0].iScore < 50) --len;

    singleOpts *siop = new singleOpts(len,opts,this);
    setCentralWidget(siop);

    connect(siop,SIGNAL(playSignal(SOptions)),this,SLOT(play(SOptions)));
    connect(siop,SIGNAL(backSignal()),this,SLOT(openMainMenu()));

}

void MainWindow::openHelp()
{
    help *hlp = new help(this);
    setCentralWidget(hlp);
    connect(hlp,SIGNAL(back()),this,SLOT(openMainMenu()));
}

void MainWindow::openScore()
{
    showNormal();
    setFixedSize(600, 400);

    Highscore *high = new Highscore(top10,this);
    setCentralWidget(high);

    connect(high,SIGNAL(ok()),this,SLOT(openMainMenu()));
}

void MainWindow::enterScore(SScoreData s)
{
    Highscore *high = new Highscore(top10,s,this);
    setCentralWidget(high);

    connect(high,SIGNAL(ok()),this,SLOT(newScore()));
}

void MainWindow::newScore()
{
    writeScore();
    openMainMenu();
}

void MainWindow::writeScore()
{
    FILE *F = fopen("Data/High.score","w");
    fwrite(top10,sizeof(SScoreData),10,F);
    fclose(F);
}

void MainWindow::readScore()
{
    FILE *F = fopen("Data/High.score","r");
    if (F)
    {
        fread(top10,sizeof(SOptions),10,F);
        fclose(F);
    }
    else for (int i=0;i<10;++i) top10[i].iScore=0;
}

void MainWindow::receiveScore(SScoreData *s)
{
    showNormal();
    setFixedSize(600, 400);

    if (opts.bSplit)
    {
        score[0] = s[0];
        score[1] = s[1];
        splitScore *ssWidget = new splitScore(score,this);
        setCentralWidget(ssWidget);
        connect(ssWidget,SIGNAL(enterScore(SScoreData)),this,SLOT(enterScore(SScoreData)));
    }
    else
    {
        score[0] = s[0];
        enterScore(score[0]);
    }
}

void MainWindow::readOpts()
{
    FILE *F = fopen("Data/Opti.ons","r");
    if (F)
    {
        fread(&opts,sizeof(SOptions),1,F);
        fclose(F);
    }
    else
    {
        opts.bFullscreen=false;
        opts.bLRTurn=false;
        opts.bLRTurn2=false;
        opts.bReverseY=false;
        opts.bReverseY2=false;
        opts.bSound=false;
        opts.bSplit=false;
        opts.iBkgnd=0;
        opts.iHeight=600;
        opts.iPerspective=5;
        opts.iPictureSize=7;
        opts.iPlayerCount=1;
        opts.iSnakeBody=0;
        opts.iSpaceX=10;
        opts.iSpaceY=10;
        opts.iSpaceZ=10;
        opts.iStartLength=0;
        opts.iTargetSize=2;
        opts.iThisPlayerNr=0;
        opts.iVelocity=2;
        opts.iWidth=800;
        writeOpts();
    }

}

void MainWindow::writeOpts()
{
    FILE *F = fopen("Data/Opti.ons","w");
    fwrite(&opts,sizeof(SOptions),1,F);
    fclose(F);
}
