#include "splitopts.h"
#include "ui_splitopts.h"

splitOpts::splitOpts(int freeLength, SOptions _opts, QWidget *parent) :
    QWidget(parent),
    m_ui(new Ui::splitOpts)
{
    opts = _opts;
    m_ui->setupUi(this);
    setOptions();
    connect(m_ui->Back,SIGNAL(clicked()),this,SLOT(backSlot()));
    connect(m_ui->Play,SIGNAL(clicked()),this,SLOT(playSlot()));
    connect(m_ui->full,SIGNAL(clicked()),this,SLOT(fullChanged()));
    m_ui->sound->setEnabled(false);
    fullChanged();
    for (int i=4;i>freeLength;--i) m_ui->length->removeItem(i);
}

splitOpts::~splitOpts()
{
    delete m_ui;
}

void splitOpts::changeEvent(QEvent *e)
{
    QWidget::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        m_ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void splitOpts::backSlot()
{
    backSignal();
}

void splitOpts::playSlot()
{
    m_ui->Play->clearFocus();
    getOptions();
    playSignal(opts);
}

void splitOpts::getOptions()
{
    switch(m_ui->screen->currentIndex())
    {
        case 0: opts.iWidth = 1280;
            opts.iHeight = 960;
            break;
        case 1: opts.iWidth = 1024;
            opts.iHeight = 768;
            break;
        case 2: opts.iWidth = 800;
            opts.iHeight = 600;
            break;
        default:
            opts.iWidth = 800;
            opts.iHeight = 600;
    }
    opts.bFullscreen = (m_ui->full->checkState() == Qt::Checked);
    opts.bSound = (m_ui->sound->checkState() == Qt::Checked);
    opts.bLRTurn = m_ui->turn->isChecked();
    opts.bReverseY = m_ui->reverseY->isChecked();
    opts.bLRTurn2 = m_ui->turn_2->isChecked();
    opts.bReverseY2 = m_ui->reverseY_2->isChecked();
    opts.bSplit = true;
    opts.iBkgnd = m_ui->bkgnd->currentIndex();
    opts.iPictureSize = m_ui->pSize->value();
    opts.iPlayerCount = 2;
    opts.iSpaceX = m_ui->spaceX->value();
    opts.iSpaceY = m_ui->spaceY->value();
    opts.iSpaceZ = m_ui->spaceZ->value();
    switch(m_ui->length->currentIndex())
    {
        case 0: opts.iStartLength = 0; break;
        case 1: opts.iStartLength = 50; break;
        case 2: opts.iStartLength = 100; break;
        case 3: opts.iStartLength = 500; break;
        case 4: opts.iStartLength = -2; break;
        default: opts.iStartLength = 0;
    }
    opts.iTargetSize = m_ui->tSize->value();
    opts.iThisPlayerNr = 0;
    opts.iVelocity = m_ui->velocity->value();
    opts.iPerspective = m_ui->perspective->value();
}

void splitOpts::setOptions()
{
    switch(opts.iWidth)
    {
        case 1280: m_ui->screen->setCurrentIndex(0);
            break;
        case 1024: m_ui->screen->setCurrentIndex(1);
            break;
        case 800: m_ui->screen->setCurrentIndex(2);
            break;
        default: m_ui->screen->setCurrentIndex(2);
    }
    if(opts.bFullscreen) m_ui->full->setCheckState(Qt::Checked);
    else m_ui->full->setCheckState(Qt::Unchecked);
    if(opts.bSound) m_ui->sound->setCheckState(Qt::Checked);
    else m_ui->sound->setCheckState(Qt::Unchecked);
    if(opts.bLRTurn)
    {
        m_ui->turn->setChecked(true);
        m_ui->spin->setChecked(false);
    }
    else
    {
        m_ui->turn->setChecked(false);
        m_ui->spin->setChecked(true);
    }
    if(opts.bReverseY) m_ui->reverseY->setCheckState(Qt::Checked);
    else m_ui->reverseY->setCheckState(Qt::Unchecked);
    if(opts.bLRTurn2)
    {
        m_ui->turn_2->setChecked(true);
        m_ui->spin_2->setChecked(false);
    }
    else
    {
        m_ui->turn_2->setChecked(false);
        m_ui->spin_2->setChecked(true);
    }
    if(opts.bReverseY2) m_ui->reverseY_2->setCheckState(Qt::Checked);
    else m_ui->reverseY_2->setCheckState(Qt::Unchecked);
    m_ui->bkgnd->setCurrentIndex(opts.iBkgnd);
    m_ui->pSize->setValue(opts.iPictureSize);
    m_ui->spaceX->setValue(opts.iSpaceX);
    m_ui->spaceY->setValue(opts.iSpaceY);
    m_ui->spaceZ->setValue(opts.iSpaceZ);
    switch(opts.iStartLength)
    {
        case 0: m_ui->length->setCurrentIndex(0); break;
        case 50: m_ui->length->setCurrentIndex(1); break;
        case 100: m_ui->length->setCurrentIndex(2); break;
        case 500: m_ui->length->setCurrentIndex(3); break;
        case -2: m_ui->length->setCurrentIndex(4); break;
        default: m_ui->length->setCurrentIndex(0);
    }
    m_ui->tSize->setValue(opts.iTargetSize);
    m_ui->velocity->setValue(opts.iVelocity);
    m_ui->perspective->setValue(opts.iPerspective);
}

void splitOpts::fullChanged()
{
    if (m_ui->full->checkState() == Qt::Checked)
        m_ui->screen->setEnabled(false);
    else
        m_ui->screen->setEnabled(true);
}

